#!/bin/bash
cd "$(dirname "$0")"

# Define variables
PANEL_NAME="AffPanel"
PANEL_DIR="/opt/affpanel"
PANEL_PORT="3333"
APACHE_CONF="/etc/apache2/sites-available/affpanel.conf"
DB_FILE="$PANEL_DIR/users.db"
INSTALL_DIR="$(pwd)"

# Function to install required packages
install_dependencies() {
    echo "📦 Installing Apache, PHP, SQLite, and Bind9 DNS..."
    apt update -y
    apt install -y apache2 php-cli php-fpm php-sqlite3 sqlite3 unzip libapache2-mod-php bind9
}

# Function to set up authentication
setup_authentication() {
    echo "🔑 Setting up authentication for AffPanel..."
    read -p "Enter admin username: " ADMIN_USER
    read -s -p "Enter admin password: " ADMIN_PASS
    echo ""

    mkdir -p "$PANEL_DIR"
    cp -r "$INSTALL_DIR/panel/"* "$PANEL_DIR/"

    sqlite3 "$DB_FILE" < "$INSTALL_DIR/config/db.sql"
    HASHED_PASS=$(php -r "echo password_hash('$ADMIN_PASS', PASSWORD_BCRYPT);")
    sqlite3 "$DB_FILE" "INSERT INTO users (username, password) VALUES ('$ADMIN_USER', '$HASHED_PASS');"
}

# Function to configure Apache
configure_apache() {
    echo "🔧 Configuring Apache..."
    cp "$INSTALL_DIR/config/apache.conf" "$APACHE_CONF"
    grep -qxF "Listen 3333" /etc/apache2/ports.conf || echo "Listen 3333" >> /etc/apache2/ports.conf

    a2enmod php8.3
    a2ensite affpanel.conf
    systemctl restart apache2
}

# Function to configure firewall
configure_firewall() {
    echo "🔒 Configuring firewall..."
    ufw allow "$PANEL_PORT"/tcp
}

# Function to start services
start_services() {
    echo "🚀 Starting services..."
    systemctl enable --now apache2 bind9
    systemctl restart apache2 bind9
}

# Function to get the server's IP address
get_server_ip() {
    SERVER_IP=$(hostname -I | awk '{print $1}')
    echo "✅ Installation complete! Access AffPanel at http://$SERVER_IP:$PANEL_PORT"
}

# Run all functions
install_dependencies
setup_authentication
configure_apache
configure_firewall
start_services
get_server_ip
